<?php

/*
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Kevin Purdy <purdyk@net.oregonstate.edu                     |
// +------------------------------------------------------------------------+

/**
 *  HostHistoryDataList.php - contains the {@link ObjectHistoryDataList} class
 *
 *  @author $Author:$
 *  @package htdocs
 *  @subpackage datalists
 *  @filesource
 */

require_once(HTCLASS."/DB_DataObjectDataList.php");
require_once(HTCLASS."/DB_DataObjectDataListSource.php");


/**
 *  This class is used to display the change history of a host.
 *  @package htdocs
 *  @subpackage datalists
 */
class HostHistoryDataList extends DB_DataObjectDataList
{

    /*
     * This method sets up the data source for the host history. It pulls
     * from the object_history table.
     */

    function get_data_source()
    {
        $obj = DB_DataObject::Factory('object_history');
        $src = new DB_DataObjectDataListSource(&$obj);
        $this->set_data_source($src);
    }

    /*
     * This function sets up the table columns, specifing the names to map to the
     * fields in the database and setting which ones are searchable.  It also places
     * some constraints on the incoming data, specifically, it only gets rows for this
     * host.
     */

    function _user_setup()
    {
        $this->add_header_item(_("Comment"), '30%', "comment");
        $this->add_header_item(_("Username"), '15%', "username", SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Action Type"), '10%', "action", SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Summary"), '30%', "summary");
        $this->add_header_item(_("Date"), '15%', "date", SORTABLE);
        
        $this->_datasource->setup_db_options(array("object_type" => 'host',
                                                   "object_id" => $_REQUEST['id']));
    }
    
    /*
     * This method performs some special formatting on the date column before
     * putting it in the table. 
     */

    function build_column_item($row_data, $col_name)
    {
        switch($col_name) {
            
        case _("Date"):
            $obj = format_date($row_data['date']);
            break;
            
        default:
            $obj = parent::build_column_item($row_data, $col_name);
        }
        
        return $obj;
    }
}
