<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2006 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Frederic Wenzel <fred@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id$

/**
  * SOADataList.php - contains the {@link SOADataList} class
  *
  * @author$
  * @filesource
  * @package    htdocs
  * @subpackage datalists
  */

require_once(DAOEXT.'/soa.php');
require_once(HTCLASS.'/DB_DataObjectDataList.php');
require_once(HTCLASS.'/DB_DataObjectDataListSource.php');

/**
  * Table listing for SOA records
  *
  * @package    htdocs
  * @subpackage datalists
  */
class SOADataList extends DB_DataObjectDataList
{

//{{{   get_data_source()

    function get_data_source()
    {
        // join SOA and Domain in order to make domainname
        // displayable and searchable
        $soa = new SOA();
        $domain = new Domain();
        $soa->joinAdd($domain);
        $soa->selectAdd('domain.name AS domainname');
        // don't let the joined domain.id overwrite 'id'
        $soa->selectAdd('soa.id AS id'); 
        $src = &new DB_DataObjectDataListSource($soa);
        $this->set_data_source($src);
        $this->_default_orderby = 'domain.name';
    }

//}}}
//{{{   _user_setup()

    function _user_setup()
    {
        $this->add_header_item(_("Domain"), '20%', 'domain.name', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Primary Master"), '20%', 'primary_master', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Hostmaster"), '20%', 'hostmaster', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("delegated"), '20%', 'delegated',SORTABLE);
        $this->add_header_item(_("Action"),'20%');
        $this->_datasource->setup_db_options(array('zone' => $_SESSION['zone']));
    }

//}}}
//{{{   build_column_item()
    
    function build_column_item($row_data, $col_name)
    {
        switch ($col_name)
        {
            case _('Domain'):
                $link = web_root().'soa.php?action=show&amp;id='.$row_data['id'];
                $obj = html_a($link, $row_data[_('domainname')]);
                break;
                
            case _('Action'):
                $obj = new container();
                $obj = Module::apply_filter('action_module', $obj, $row_data, 'soa');
                break;
            case _("delegated"):
                $obj = ($row_data['delegated'] == 1 ? _('yes') : _('no'));
                break;
            default:
                $obj = parent::build_column_item($row_data, $col_name);
        }

        return $obj;
    }

//}}}

}

?>
