<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: ZoneUserAddForm.php 4628 2006-07-14 21:59:06Z bartel $

/**
 *  ZoneUserAddForm.php - Contains the {@link ZoneUserAddForm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This class is the form that is used to add and remove user to/from the zone
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class ZoneUserAddForm extends MaintainForm
{

//{{{   form_init_elements()

    /**
     *  This method sets up all the form elements and initializes them
     */
    function form_init_elements()
    {
        global $user;
        
        $name = new FEText(_("Username"), false);
        $access = new FEListBox(_("Access Level"));
        $allzone = new FECheckBox(_("All My Zones"));

        $access->set_list_data(array("User"=>ZONE_USER,
                                    "Guest"=>GUEST,
                                    "Zone Admin"=>ZONE_ADMIN));
        $addbut = new FESubmitButton(_("Add"), _("Add"));

        $this->add_elements($name, $access, $addbut);
        if(!$user->is_admin())
            $this->add_element($allzone);
    }

//}}}
//{{{   form()
    function form()
    {
        $div = html_div("form");
        $table = html_table();

        $td = html_td();
        $td->add(
                $this->element_form(_("Username")),
                $this->element_form(_("Access Level")));

        $tr = html_tr("even");
        $tr->add($this->element_label(_("Username")),
                $td,
                $this->add_action(_("Add"))); 
        $table->add($tr);
        
        $div->add($table);
        $div->add($this->form_hidden());
        return $div;
    }
//}}}
//{{{   form_backend_validation()

    /**
     *  We need to make sure that the target user exists, otherwise this is 
     *  going to break foreign keys.
     *
     *  @return Boolean     True if the user exists
     */
    function form_backend_validation()
    {
        $res = true;
        
        $vals = $this->get_all_element_values();
    
        //Check for duplicates
        $zu = DB_DataObject::Factory('zone_user');
        $zu->zone = $_SESSION['zone'];
        $zu->username = $vals[_("Username")];
        $zu->whereAdd("level = {$vals['Access_Level']}");
        if ($zu->find())    {
            $this->add_error(_("Username"), _("User already in this zone with the permission"));
            $res = false;
        }

        if ($vals[_('Username')] == '') {
            $this->add_error(_("Username"), _("Please specify a user name to be added to zone."));
            return false;
        }
        
        $usr = DB_DataObject::Factory('user');
        $usr->username = $vals[_("Username")];
        
        if($usr->find() === 0) {
            $this->add_error(_("Username"), 
                            _("Specified user is not in the user table"));
            return false;
        }
        return $res;
    }

//}}}
//{{{   form_action()

    /**
     *  This method adds the target user to the target zones if said user exists.
     *
     *  @return Boolean     True if user was successfully added to zones
     */
    function form_action()
    {
        global $user;
        $res = true;
    
        switch(strtolower($this->get_action())) {

        case 'add':
            $zn = DB_DataObject::Factory('zone_user');
            $zn->query("BEGIN");            
            $vals = $this->get_all_element_values(); //get form values
            
            $zn->username = $vals[_("Username")]; //zone user we're making
            $zn->level = $vals[_("Access_Level")];    
            
            $trgtusr = new User($vals[_("Username")]);
            
//{{{            //If they want to add to ALL of their zones
            if(isset($vals[_("All_My_Zones")])) {
                $zoneusr = DB_DataObject::Factory('zone_user');
                $zoneusr->username = $user->username;
                $zoneusr->find();

                //While there are zones for that user
                while($zoneusr->fetch()) {
                
                    //set the zone    
                    $zn->zone = $zoneusr->zone;
                  
                    //don't add them if they're already there or a full admin
                    //or the adding user isn't a zone admin to the target zone
                    if($zn->find() || $trgtusr->is_admin() || 
                        !$user->is_zone_admin($zoneusr->zone))
                        continue;
                    
                    //if insert fails
                    if(!$zn->insert()) {
                        $zn->query("ROLLBACK");
                        //report an error
                        $this->add_error(_("ERROR"), 
                            _("Could not add user information to database for zone").
                            ' '.$zn->zone);
                        //Not successful    
                        $res = false;
                    } else {
                        $zn->query("COMMIT");
                        $zn->write_history(_("Added user ").' '.$zn->username.' '.
                                            _("to zone"), ACTION_MODIFY, $user->username,
                                            $zn->zone);
                    }
                        
                }
                
            } else { //just adding to global zone
                //set zone
//}}}
                $zn->zone = $_SESSION['zone'];
                
                //attempt to insert
                if(!$zn->find() && !$trgtusr->is_admin()) {
                    
                    if(!$zn->insert()) {
                        $zn->query("ROLLBACK");
                        //report error on failure
                        $this->add_error(_("ERROR"),_("Could not add user to zone"));
                        $res = false;
                    } else {
                        $zn->query("COMMIT");
                        $zn->write_history(_("Added user ").' '.$zn->username.' '.
                                            _("to zone"), ACTION_MODIFY, $user->username,
                                            $zn->zone);
                    }
                    
                }
            }

            break; 
            
        default:
            die_hard(_("Invalid form action"));
            break;

        }
        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  Method that displays a very simple success message and way for them to go
     *  back to their dashoboard or the user list.
     *
     *  @return DIVTag  $div    Div with the success message inside
     */
    function form_success() 
    {
        /* only way I can find to reload the user list data 
        header("Location: ".web_root()."zone.php?action=".$_REQUEST['action'].
                                                "&id=".$_REQUEST['id']);
        */
        $vals = $this->get_all_element_values();
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php", _("[Return to Index]"));
        $usrlink = html_a(web_root()."user.php",_("[Return to User List]"));
        $div->add(_("User successfully added:"), html_br(),$vals['Username']);
        $div->add(' '._("with access level").' '.
                User::access_level($vals[_("Access_Level")]),html_br());
        $div->add($indlink,$usrlink);

        return $div;
    }

//}}}
//{{{   _zone_users()
    /*
     *  Gets a displayable list of all users in this zone.
     *  usernam => username
     *
     *  @return Array
     */
    function _zone_users()
    {
        $ary = array();

        $db = DB_DataObject::Factory('zone_user');
        $db->zone = $_SESSION['zone'];
        $db->orderBy('username');

        $db->find();
        while ($db->fetch())
            $ary[$db->username] = $db->username;
        return $ary;
    }
//}}}
//{{{   form_hidden()
    function form_hidden()
    {
        /* Need to remember action and id */
        $cont = container();
        $act = new FEHidden("action", $_REQUEST['action']);
        $idnum = new FEHidden("id",$_REQUEST['id']);
        $this->add_elements($act, $idnum);
        $cont->add($this->element_form("action"),$this->element_form("id"));
        return $cont;
    }
}


?>
